<?php

namespace FiloBlu\Cegid\Setup;

use Magento\Framework\DB\Adapter\AdapterInterface;
use Magento\Framework\DB\Ddl\Table;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;
use Magento\Framework\Setup\UpgradeSchemaInterface;
use Zend_Db_Exception;

/**
 * Class UpgradeSchema
 * @package FiloBlu\Cegid\Setup
 */
class UpgradeSchema implements UpgradeSchemaInterface
{

    /**
     * @param SchemaSetupInterface $setup
     * @param ModuleContextInterface $context
     * @throws Zend_Db_Exception
     */
    public function upgrade(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        $setup->startSetup();

        if (version_compare($context->getVersion(), '1.0.1', '<')) {
            $this->addQuoteExtensionTable($setup);
        }

        if (version_compare($context->getVersion(), '1.0.2', '<')) {
            $this->addCreditMemoExtFlag($setup);
        }

        $setup->endSetup();
    }

    /**
     * @param SchemaSetupInterface $setup
     * @throws Zend_Db_Exception
     * @throws Zend_Db_Exception
     */
    public function addQuoteExtensionTable(SchemaSetupInterface $setup)
    {
        $tableName = $setup->getTable('filoblu_cegid_quote_extension');
        if ($setup->tableExists($tableName)) {
            return;
        }
        $table = $setup->getConnection()->newTable($tableName);
        $table->addColumn('quote_id',
            Table::TYPE_INTEGER,
            null,
            ['unsigned' => true, 'nullable' => false, 'primary' => true],
            'Quote ID')
            ->addColumn(
                'seller_id',
                Table::TYPE_TEXT,
                255,
                [],
                'Cegid id'
            )
            ->addIndex(
                $setup->getIdxName($table->getName(), ['seller_id']),
                ['seller_id'],
                AdapterInterface::INDEX_TYPE_INDEX
            )
            ->addForeignKey(
                $setup->getFkName($table->getName(), 'quote_id', 'quote', 'entity_id'),
                'quote_id',
                $setup->getTable('quote'),
                'entity_id',
                Table::ACTION_CASCADE
            );
        $setup->getConnection()->createTable($table);
    }


    public function addCreditMemoExtFlag(SchemaSetupInterface $setup)
    {
        $tableName = $setup->getTable('sales_creditmemo');
        if (!$setup->tableExists($tableName)) {
            return;
        }

        $setup->getConnection()
            ->addColumn($tableName,'sent_to_ext', array(
                'type'      => 'smallint',
                'nullable'  => false,
                'length'    => 5,
                'after'     => null, // column name to insert new column after
                'comment'   => 'Flag 1 if this creditmemo have been sent to external sources',
                'default'   => '0'
            ));
        $setup->endSetup();
    }
}